@@ -11,28 +11,22 @@ from vfscript.training.training_graph import AtomicGraphGenerator
 from vfscript.gui.common import load_params, save_params, render_dump_to
 from vfscript.training.preparer import TrainingPreparer
 
-
 # Forzar backend XCB en Wayland
 os.environ["QT_QPA_PLATFORM"] = "xcb"
 
-
 from PySide6.QtCore import Qt
 from PySide6.QtWidgets import (
     QApplication, QMainWindow, QWidget, QFormLayout, QCheckBox,
     QDoubleSpinBox, QSpinBox, QLineEdit, QPushButton, QFileDialog,
     QMessageBox, QHBoxLayout, QPlainTextEdit, QVBoxLayout,
     QProgressBar, QSizePolicy, QComboBox, QTableWidget, QTableWidgetItem,
-    QScrollArea, QLabel, QTabWidget,QGroupBox  
+    QScrollArea, QLabel, QTabWidget, QGroupBox
 )
 from pyvistaqt import QtInteractor
 import pyvista as pv
 import numpy as np
-from ovito.io import import_file
-from vfscript import vfs
-import pandas as pd
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
-from vfscript.training.preparer import *
 
 
 class TrainingTab(QWidget):
@@ -40,6 +34,48 @@ class TrainingTab(QWidget):
     Pestaña 'Training' para configurar generación de red perfecta y features.
     Guarda en params['CONFIG'][0]['training_setup'].
     """
+    # ---------------------- utilidades internas ----------------------
+    def _msg(self, title, text, kind="info"):
+        try:
+            fn = {
+                "info": QMessageBox.information,
+                "warn": QMessageBox.warning,
+                "err": QMessageBox.critical,
+            }.get(kind, QMessageBox.information)
+            fn(self, title, text)
+        except Exception:
+            print(f"[{kind}] {title}: {text}")
+
+    def _gw(self, name, default=None):
+        """Get Widget: intenta value(), text(), currentText(), isChecked()."""
+        w = getattr(self, name, None)
+        if w is None:
+            return default
+        for attr in ("value", "text", "currentText", "isChecked"):
+            fn = getattr(w, attr, None)
+            if callable(fn):
+                try:
+                    v = fn()
+                    return v.strip() if isinstance(v, str) else v
+                except Exception:
+                    pass
+        return default
+
+    def _sw(self, name, value):
+        """Set Widget: intenta setValue(), setText(), setCurrentText(), setChecked()."""
+        w = getattr(self, name, None)
+        if w is None:
+            return
+        for attr in ("setValue", "setText", "setCurrentText", "setChecked"):
+            fn = getattr(w, attr, None)
+            if callable(fn):
+                try:
+                    fn(value)
+                    return
+                except Exception:
+                    pass
+
+    # --------------------------- constructor ---------------------------
     def __init__(self, parent=None):
         super().__init__(parent)
         self.parent = parent
@@ -70,7 +106,7 @@ class TrainingTab(QWidget):
         self.edit_atom = QLineEdit(tr.get('perfect_network', {}).get('atom', "Fe"))
 
         btn_gen = QPushButton("Generar red perfecta")
-        btn_gen.clicked.connect(self._generate_stub)
+        btn_gen.clicked.connect(self._generate_stub)   # genera outputs/json/training_inputs.json
 
         form_net.addRow("Lattice:", self.combo_lattice)
         form_net.addRow("a₀ (Å):", self.spin_a0)
@@ -79,7 +115,6 @@ class TrainingTab(QWidget):
         form_net.addRow("Réplicas Z:", self.spin_rz)
         form_net.addRow("Elemento:", self.edit_atom)
         form_net.addRow(btn_gen)
-
         root.addWidget(box_net)
 
         # ===== Sección: Configuración de entrenamiento =====
@@ -104,9 +139,7 @@ class TrainingTab(QWidget):
         row_coord = QHBoxLayout()
         self.chk_coord = QCheckBox("Coordinación")
         self.spin_rc = QDoubleSpinBox()
-        self._cfg_spin(self.spin_rc, 0.0, 20.0,
-                       float(tr.get('features', {}).get('coordination', {}).get('rc', 3.25)),
-                       step=0.01, decimals=2)
+        self._cfg_spin(self.spin_rc, 0.0, 20.0, float(tr.get('features', {}).get('coordination', {}).get('rc', 3.25)), step=0.01, decimals=2)
         row_coord.addWidget(self.chk_coord)
         row_coord.addStretch()
         row_coord.addWidget(QLabel("rc (Å):"))
@@ -121,9 +154,7 @@ class TrainingTab(QWidget):
         row_s = QHBoxLayout()
         self.chk_steinhardt = QCheckBox("Steinhardt Q_l")
         self.spin_qr = QDoubleSpinBox()
-        self._cfg_spin(self.spin_qr, 0.0, 20.0,
-                       float(tr.get('features', {}).get('steinhardt', {}).get('radius', 2.70)),
-                       step=0.01, decimals=2)
+        self._cfg_spin(self.spin_qr, 0.0, 20.0, float(tr.get('features', {}).get('steinhardt', {}).get('radius', 2.70)), step=0.01, decimals=2)
         row_s.addWidget(self.chk_steinhardt)
         row_s.addStretch()
         row_s.addWidget(QLabel("r (Å):"))
@@ -146,24 +177,20 @@ class TrainingTab(QWidget):
         feat_layout.addLayout(row_hull)
 
         root.addWidget(box_feat)
+
         # ===== Preview de red =====
         box_prev = QGroupBox("Preview de red")
         prev_layout = QVBoxLayout(box_prev)
-
-        # Etiqueta con el total de átomos
         self.lbl_atoms = QLabel("Átomos totales: -")
         prev_layout.addWidget(self.lbl_atoms)
-
-        # Vistas 3D y 2D
         self.preview_plotter = QtInteractor(box_prev)
         prev_layout.addWidget(self.preview_plotter)
         self.preview_fig = plt.figure(figsize=(4, 4))
         self.preview_canvas = FigureCanvas(self.preview_fig)
         prev_layout.addWidget(self.preview_canvas)
-
         root.addWidget(box_prev)
 
-        # === Señales para refrescar preview y contador ===
+        # Señales para refrescar preview y contador
         self.combo_lattice.currentTextChanged.connect(self.update_preview)
         self.spin_a0.valueChanged.connect(self.update_preview)
         self.spin_rx.valueChanged.connect(self.update_preview)
@@ -173,18 +200,17 @@ class TrainingTab(QWidget):
         # Render inicial del preview
         self.update_preview()
 
-
         # ===== Botones guardar/cargar =====
         row_btns = QHBoxLayout()
         btn_save = QPushButton("Guardar configuración")
         btn_load = QPushButton("Cargar configuración actual")
-        btn_prepare = QPushButton("Preparar dataset")  # ⬅️ nuevo
+        btn_prepare = QPushButton("Preparar dataset")
         btn_save.clicked.connect(self.save_training_setup)
-        btn_load.clicked.connect(self.load_from_params)
-        btn_prepare.clicked.connect(self.on_prepare_training_clicked)  # ⬅️ nuevo
+        btn_load.clicked.connect(self.load_from_params)        # <- ahora existe
+        btn_prepare.clicked.connect(self.on_prepare_training_clicked)
         row_btns.addWidget(btn_save)
         row_btns.addWidget(btn_load)
-        row_btns.addWidget(btn_prepare)  # ⬅️ nuevo
+        row_btns.addWidget(btn_prepare)
         root.addLayout(row_btns)
 
         # ===== Estados iniciales de checks =====
@@ -202,10 +228,9 @@ class TrainingTab(QWidget):
         self.chk_hull.setChecked(hull.get('enabled', False))
         self.chk_area.setChecked(hull.get('area', True))
         self.chk_vol.setChecked(hull.get('volume', True))
-        # Log local de la pestaña (debajo de los botones)
-        self.log_box = QPlainTextEdit()
-        self.log_box.setReadOnly(True)
-        self.log_box.setMinimumHeight(120)
+
+        # Log local de la pestaña
+        self.log_box = QPlainTextEdit(); self.log_box.setReadOnly(True); self.log_box.setMinimumHeight(120)
         root.addWidget(self.log_box)
 
         # Habilitar/deshabilitar sub-opciones
@@ -235,57 +260,154 @@ class TrainingTab(QWidget):
             spin.setSingleStep(int(step))
         spin.setValue(val)
 
-    # ===== Acciones =====
+    # ===================== persistencia/IO =====================
     def save_training_setup(self):
-        params = load_params()
-        cfg = params.setdefault('CONFIG', [{}])[0]
+        """Guarda en params['CONFIG'][0]['training_setup'] y además exporta un JSON de compatibilidad."""
         setup = {
             'iterations': int(self.spin_iters.value()),
             'max_vacancies': int(self.spin_max_vacs.value()),
             'features': {
-                'coordination': {'enabled': self.chk_coord.isChecked(), 'rc': float(self.spin_rc.value())},
-                'energy_potential': {'enabled': self.chk_energy.isChecked()},
+                'coordination': {
+                    'enabled': self.chk_coord.isChecked(),
+                    'rc': float(self.spin_rc.value()),
+                },
+                'energy_potential': {
+                    'enabled': self.chk_energy.isChecked(),
+                },
                 'steinhardt': {
                     'enabled': self.chk_steinhardt.isChecked(),
                     'radius': float(self.spin_qr.value()),
                     'orders': {
-                        'Q4': self.chk_Q4.isChecked(), 'Q6': self.chk_Q6.isChecked(),
-                        'Q8': self.chk_Q8.isChecked(), 'Q10': self.chk_Q10.isChecked(),
-                        'Q12': self.chk_Q12.isChecked()
-                    }
+                        'Q4': self.chk_Q4.isChecked(),
+                        'Q6': self.chk_Q6.isChecked(),
+                        'Q8': self.chk_Q8.isChecked(),
+                        'Q10': self.chk_Q10.isChecked(),
+                        'Q12': self.chk_Q12.isChecked(),
+                    },
+                },
+                'convex_hull': {
+                    'enabled': self.chk_hull.isChecked(),
+                    'area': self.chk_area.isChecked(),
+                    'volume': self.chk_vol.isChecked(),
                 },
-                'convex_hull': {'enabled': self.chk_hull.isChecked(),
-                                'area': self.chk_area.isChecked(),
-                                'volume': self.chk_vol.isChecked()},
             },
             'perfect_network': {
                 'lattice': self.combo_lattice.currentText(),
                 'a0': float(self.spin_a0.value()),
                 'cells': [int(self.spin_rx.value()), int(self.spin_ry.value()), int(self.spin_rz.value())],
                 'atom': self.edit_atom.text().strip() or "Fe",
-            }
+            },
         }
-        cfg['training_setup'] = setup
-        path = save_params(params)
-        QMessageBox.information(self, "Training guardado",
-                                f"Se guardó training_setup en:\n{path}")
+
+        # Actualiza params y persiste con save_params
+        self.cfg['training_setup'] = setup
+        try:
+            save_params(self.params)
+        except Exception as e:
+            self._msg("Advertencia", f"No se pudo guardar con save_params():\n{e}", "warn")
+
+        # Export JSON de compatibilidad para pipelines que esperan outputs/json/training_inputs.json
+        # Incluimos training_setup dentro de CONFIG[0]; otras claves (relax/cutoff/...) pueden venir de otras pestañas o del stub.
+        out_dir = Path("outputs/json"); out_dir.mkdir(parents=True, exist_ok=True)
+        export_path = out_dir / "training_inputs.json"
+        compat = {"CONFIG": [{"training_setup": setup}]}
+        try:
+            with open(export_path, "w", encoding="utf-8") as f:
+                json.dump(compat, f, indent=4)
+        except Exception as e:
+            self._msg("Advertencia", f"No se pudo escribir {export_path}:\n{e}", "warn")
+
+        self._msg("Training guardado", f"Configuración exportada a:\n{export_path}")
 
     def load_from_params(self):
-        # Recarga simple (si cambió el JSON fuera de la pestaña)
-        self.__init__(self.parent)
+        """Carga params['CONFIG'][0]['training_setup'] a la UI (si existe)."""
+        try:
+            self.params = load_params()
+            self.cfg = self.params.setdefault('CONFIG', [{}])[0]
+            tr = self.cfg.get('training_setup', {})
 
+            # perfect_network
+            pn = tr.get('perfect_network', {})
+            self._sw('combo_lattice', pn.get('lattice', 'fcc'))
+            try:
+                self.spin_a0.setValue(float(pn.get('a0', self.spin_a0.value())))
+            except Exception:
+                pass
+            cells = pn.get('cells', [self.spin_rx.value(), self.spin_ry.value(), self.spin_rz.value()])
+            if isinstance(cells, (list, tuple)) and len(cells) == 3:
+                self._sw('spin_rx', int(cells[0])); self._sw('spin_ry', int(cells[1])); self._sw('spin_rz', int(cells[2]))
+            self._sw('edit_atom', pn.get('atom', 'Fe'))
+
+            # features
+            ft = tr.get('features', {})
+            crd = ft.get('coordination', {})
+            self._sw('chk_coord', bool(crd.get('enabled', True)))
+            try:
+                self.spin_rc.setValue(float(crd.get('rc', self.spin_rc.value())))
+            except Exception:
+                pass
+            self._sw('chk_energy', bool(ft.get('energy_potential', {}).get('enabled', True)))
+
+            st = ft.get('steinhardt', {})
+            self._sw('chk_steinhardt', bool(st.get('enabled', True)))
+            try:
+                self.spin_qr.setValue(float(st.get('radius', self.spin_qr.value())))
+            except Exception:
+                pass
+            od = st.get('orders', {})
+            self._sw('chk_Q4',  bool(od.get('Q4', True)))
+            self._sw('chk_Q6',  bool(od.get('Q6', True)))
+            self._sw('chk_Q8',  bool(od.get('Q8', False)))
+            self._sw('chk_Q10', bool(od.get('Q10', False)))
+            self._sw('chk_Q12', bool(od.get('Q12', False)))
+
+            hull = ft.get('convex_hull', {})
+            self._sw('chk_hull', bool(hull.get('enabled', False)))
+            self._sw('chk_area', bool(hull.get('area', True)))
+            self._sw('chk_vol',  bool(hull.get('volume', True)))
+
+            self.update_preview()
+            self._msg("OK", "Parámetros cargados en la interfaz.")
+        except Exception as e:
+            self._msg("Error", f"No se pudo cargar la configuración:\n{e}", "err")
+
+    # ===================== acciones principales =====================
     def _generate_stub(self):
-        # Por ahora solo fuerza un refresh visual.
-        self.update_preview()
-        QMessageBox.information(
-            self, "Generar red perfecta",
-            "Preview actualizado con los parámetros actuales. Conectar aquí tu lógica de exportar .dump cuando lo tengas."
-        )
+        """
+        Genera outputs/json/training_inputs.json para pipelines que esperan CONFIG.
+        Toma valores si existen en esta pestaña; donde no, usa defaults.
+        """
+        try:
+            def _num(x, dflt):
+                try:
+                    return float(x)
+                except Exception:
+                    return dflt
 
+            cfg = {
+                "CONFIG": [{
+                    # Claves usadas por AtomicGraphGenerator
+                    "relax": self._gw("edit_relax_path", ""),
+                    "cutoff": _num(self._gw("spin_cutoff", 3.25), 3.25),
+                    "radius": _num(self._gw("spin_radius", 2.70), 2.70),
+                    "smoothing_level_training": int(self._gw("spin_smoothing", 2) or 2),
+                    "max_graph_variations": int(self._gw("spin_variations", 1) or 1),
+                    "max_graph_size": int(self._gw("spin_max_nodes", 16) or 16),
+                    # Además guardamos el bloque training_setup de esta pestaña (si existe)
+                    "training_setup": self.cfg.get('training_setup', {}),
+                }]
+            }
+            out = Path.cwd() / "outputs/json/training_inputs.json"
+            out.parent.mkdir(parents=True, exist_ok=True)
+            with open(out, "w", encoding="utf-8") as f:
+                json.dump(cfg, f, indent=2, ensure_ascii=False)
+            self._msg("Listo", f"Se generó:\n{out}")
+        except Exception as e:
+            self._msg("Error", f"No se pudo generar el stub:\n{e}", "err")
 
     def on_prepare_training_clicked(self):
         params = load_params()
-        setup_dict = params['CONFIG'][0]['training_setup']
+        setup_dict = params['CONFIG'][0].get('training_setup', {})
         out_dir = Path('outputs/training')
 
         def log_to_gui(msg: str):
@@ -298,37 +420,27 @@ class TrainingTab(QWidget):
         try:
             prep.validate()
             prep.prepare_workspace()
-            ref_dump = prep.generate_perfect_dump()  # opcional
-            csv = prep.build_dataset_csv([ref_dump])  # dataset base
+            ref_dump = prep.generate_perfect_dump()      # opcional
+            _ = prep.build_dataset_csv([ref_dump])       # dataset base
 
             log_to_gui("🔄 Ejecutando AtomicGraphGenerator...")
             gen = AtomicGraphGenerator()
             gen.run()
             log_to_gui("✔️ Entrenamiento finalizado. Dataset en outputs/csv/finger_data.csv")
 
-            QMessageBox.information(
-                self,
+            self._msg(
                 "Entrenamiento completado",
                 "Dataset generado y entrenamiento terminado.\n"
-                "Ver archivos en outputs/csv/finger_data.csv y outputs/json/training_graph.json"
+                "Ver archivos en outputs/csv/finger_data.csv"
             )
-
         except Exception as e:
-            QMessageBox.critical(self, "Error en preparación/entrenamiento", str(e))
+            self._msg("Error en preparación/entrenamiento", str(e), "err")
 
-        # ======== PREVIEW: generación de red y render ========
+    # ===================== preview geométrico =====================
     def _make_lattice_points(self, lattice: str, a0: float, rx: int, ry: int, rz: int) -> np.ndarray:
-        """
-        Genera posiciones (N,3) para una red cúbica convencional replicada.
-        - lattice: 'fcc' o 'bcc'
-        - a0: parámetro de red (Å)
-        - rx, ry, rz: réplicas en cada eje
-        """
         lattice = (lattice or "fcc").strip().lower()
         if lattice not in ("fcc", "bcc"):
             lattice = "fcc"
-
-        # Bases fraccionarias en la celda cúbica convencional
         if lattice == "fcc":
             basis = np.array([
                 [0.0, 0.0, 0.0],
@@ -341,18 +453,13 @@ class TrainingTab(QWidget):
                 [0.0, 0.0, 0.0],
                 [0.5, 0.5, 0.5],
             ], dtype=float)
-
-        # Grid de réplicas
         ii, jj, kk = np.mgrid[0:rx, 0:ry, 0:rz]
-        cells = np.stack([ii.ravel(), jj.ravel(), kk.ravel()], axis=1).astype(float)  # (rx*ry*rz, 3)
-
-        # Posiciones: (n_cells,1,3) + (1,n_basis,3)  -> broadcast -> (n_cells,n_basis,3)
+        cells = np.stack([ii.ravel(), jj.ravel(), kk.ravel()], axis=1).astype(float)
         pos = cells[:, None, :] + basis[None, :, :]
         pos = pos.reshape(-1, 3) * a0
         return pos
 
     def _draw_box_edges(self, ax2d, Lx, Ly, Lz):
-        # Esquinas del paralelepípedo (cubo replicado)
         corners = np.array([
             [0, 0, 0],
             [Lx, 0, 0],
@@ -376,7 +483,6 @@ class TrainingTab(QWidget):
             x0, y0 = corners[i][0], corners[i][1]
             x1, y1 = corners[j][0], corners[j][1]
             ax2d.plot([x0, x1], [y0, y1], '-', linewidth=1)
-
         ax2d.set_xlabel("X"); ax2d.set_ylabel("Y")
         ax2d.set_aspect("equal", "box"); ax2d.grid(True, linewidth=0.3)
 
@@ -403,113 +509,18 @@ class TrainingTab(QWidget):
 
             # 3D
             self.preview_plotter.clear()
-            # Caja
-            self._draw_box_edges(self.preview_fig.gca() if self.preview_fig.axes else self.preview_fig.add_subplot(111),
-                                Lx, Ly, Lz)  # esto además resetea 2D
+            # Caja + reset de 2D
+            ax = self.preview_fig.gca() if self.preview_fig.axes else self.preview_fig.add_subplot(111)
+            self._draw_box_edges(ax, Lx, Ly, Lz)
             # Puntos 3D
             self.preview_plotter.add_mesh(
-                pv.PolyData(pts),
-                color="black",
-                render_points_as_spheres=True,
-                point_size=6
+                pv.PolyData(pts), color="black", render_points_as_spheres=True, point_size=6
             )
-            self.preview_plotter.reset_camera()
-            self.preview_plotter.set_scale(1, 1, 1)
+            self.preview_plotter.reset_camera(); self.preview_plotter.set_scale(1, 1, 1)
 
-            # 2D XY (sobre la figura que ya reseteamos dentro de _draw_box_edges)
+            # 2D XY
             ax2d = self.preview_fig.axes[0]
             ax2d.scatter(pts[:, 0], pts[:, 1], s=6, color="k")
             self.preview_canvas.draw()
-
-        except Exception as e:
-            # Si algo falla, no rompemos la UI: mostramos el error en el label
-            self.lbl_atoms.setText(f"Error en preview: {e}")
-
-    # ======== PREVIEW: generación de red y render ========
-    def _make_lattice_points(self, lattice: str, a0: float, rx: int, ry: int, rz: int) -> np.ndarray:
-        lattice = (lattice or "fcc").strip().lower()
-        if lattice not in ("fcc", "bcc"):
-            lattice = "fcc"
-
-        if lattice == "fcc":
-            basis = np.array([
-                [0.0, 0.0, 0.0],
-                [0.0, 0.5, 0.5],
-                [0.5, 0.0, 0.5],
-                [0.5, 0.5, 0.0],
-            ], dtype=float)
-        else:  # bcc
-            basis = np.array([
-                [0.0, 0.0, 0.0],
-                [0.5, 0.5, 0.5],
-            ], dtype=float)
-
-        ii, jj, kk = np.mgrid[0:rx, 0:ry, 0:rz]
-        cells = np.stack([ii.ravel(), jj.ravel(), kk.ravel()], axis=1).astype(float)
-        pos = cells[:, None, :] + basis[None, :, :]
-        pos = pos.reshape(-1, 3) * a0
-        return pos
-
-    def _draw_box_edges(self, ax2d, Lx, Ly, Lz):
-        corners = np.array([
-            [0, 0, 0],
-            [Lx, 0, 0],
-            [0, Ly, 0],
-            [0, 0, Lz],
-            [Lx, Ly, 0],
-            [Lx, 0, Lz],
-            [0, Ly, Lz],
-            [Lx, Ly, Lz]
-        ], dtype=float)
-        edges = [(0,1),(0,2),(0,3),(1,4),(1,5),(2,4),(2,6),(3,5),(3,6),(4,7),(5,7),(6,7)]
-
-        self.preview_plotter.clear()
-        for i, j in edges:
-            self.preview_plotter.add_mesh(pv.Line(corners[i], corners[j]), color="blue", line_width=2)
-
-        ax2d.cla()
-        for i, j in edges:
-            x0, y0 = corners[i][0], corners[i][1]
-            x1, y1 = corners[j][0], corners[j][1]
-            ax2d.plot([x0, x1], [y0, y1], '-', linewidth=1)
-        ax2d.set_xlabel("X"); ax2d.set_ylabel("Y")
-        ax2d.set_aspect("equal", "box"); ax2d.grid(True, linewidth=0.3)
-
-    def update_preview(self):
-        try:
-            lattice = self.combo_lattice.currentText().strip().lower()
-            a0 = float(self.spin_a0.value())
-            rx = int(self.spin_rx.value())
-            ry = int(self.spin_ry.value())
-            rz = int(self.spin_rz.value())
-
-            pts = self._make_lattice_points(lattice, a0, rx, ry, rz)
-            n_atoms = int(pts.shape[0])
-            self.lbl_atoms.setText(f"Átomos totales: {n_atoms}")
-
-            Lx, Ly, Lz = rx * a0, ry * a0, rz * a0
-
-            self.preview_plotter.clear()
-            self._draw_box_edges(self.preview_fig.gca() if self.preview_fig.axes else self.preview_fig.add_subplot(111),
-                                Lx, Ly, Lz)
-            self.preview_plotter.add_mesh(
-                pv.PolyData(pts),
-                color="black",
-                render_points_as_spheres=True,
-                point_size=6
-            )
-            self.preview_plotter.reset_camera()
-            self.preview_plotter.set_scale(1, 1, 1)
-
-            ax2d = self.preview_fig.axes[0]
-            ax2d.scatter(pts[:, 0], pts[:, 1], s=6, color="k")
-            self.preview_canvas.draw()
-
         except Exception as e:
             self.lbl_atoms.setText(f"Error en preview: {e}")
-
-
-
-
-
-
