@@ -19,7 +19,7 @@ from vfscript.training.utils import resolve_input_params_path
 class AtomicGraphGenerator:
     def __init__(self, json_params_path: str = None):
         if json_params_path is None:
-            json_params_path = resolve_input_params_path("input_params.json")
+            json_params_path = resolve_input_params_path("outputs/json/training_inputs.json")
         cfg = json.load(open(json_params_path))["CONFIG"][0]
         self.input_path = cfg['relax']
         self.cutoff    = cfg['cutoff']
