@@ -33,6 +33,25 @@ def VacancyAnalysis():
         dump_path = cs_generator.generate()
         #print(f"Estructura relajada generada en: {dump_path}")
         if configuracion['training']:
+        # 1) Recuperar el dict que guarda tu pestaña (CONFIG[0]['training_setup'])
+     
+            params = json.load(open("input_params.json", "r", encoding="utf-8"))
+            setup_dict = params["CONFIG"][0]["training_setup"]
+
+            # 2) Construir el preparador
+            prep = TrainingPreparer.from_setup_dict(setup_dict, out_dir=Path("outputs/training"),
+                                                    logger=lambda m: print("[training]", m))
+
+            # 3) Validar + preparar entorno
+            prep.validate()
+            prep.prepare_workspace()
+
+            # 4) (Opcional) generar una red perfecta .dump para pruebas
+            dump_ref = prep.generate_perfect_dump()  # outputs/training/relax_structure.dump
+
+            # 5) Extraer features de uno o varios dumps y generar CSV
+            csv_path = prep.build_dataset_csv([dump_ref])   # o bien una lista de dumps reales tuyos
+            print("Dataset listo en:", csv_path)
             gen = AtomicGraphGenerator()
             gen.run()
             p = argparse.ArgumentParser(description="Exporta features (normas + ConvexHull) a CSV.")
@@ -58,6 +77,12 @@ def VacancyAnalysis():
         method = analyzer.select_method()
         #print(f"Métrica δ = {delta:.4f}, método seleccionado: {method}")
         
+
+
+
+
+
+
         # 2) Condicional
         if method == 'geometric' and configuracion['geometric_method']:
             # Aplico el método geométrico
